﻿using System.Windows;
using Infragistics.Controls.Grids;

namespace LongTextColumnPOC
{
    public class LongTextColumn : EditableColumn
    {
        public LongTextColumn()
        {
            this.AllowToolTips = AllowToolTips.Never;

            base.AddNewRowItemTemplateVerticalContentAlignment = (base.VerticalContentAlignment = VerticalAlignment.Stretch);
            base.AddNewRowItemTemplateHorizontalContentAlignment = (base.HorizontalContentAlignment = HorizontalAlignment.Stretch);
        }

        protected override Infragistics.Controls.Grids.Primitives.ColumnContentProviderBase GenerateContentProvider()
        {
            return new LongTextColumnContentProvider();
        }

        public readonly static DependencyProperty MaxLengthProperty =
                DependencyProperty.Register("MaxLength", typeof(int?), typeof(LongTextColumn));

        public int? MaxLength
        {
            get { return (int?)GetValue(MaxLengthProperty); }
            set
            {
                SetValue(MaxLengthProperty, value);
            }
        }
       

        public readonly static DependencyProperty IsLongTextReadOnlyProperty =
                DependencyProperty.Register("IsLongTextReadOnly", typeof(bool), typeof(LongTextColumn), new PropertyMetadata(new PropertyChangedCallback(IsLongTextReadOnlyChanged)));

        public bool IsLongTextReadOnly
        {
            get { return (bool)GetValue(IsLongTextReadOnlyProperty); }
            set
            {
                SetValue(IsLongTextReadOnlyProperty, value);
            }
        }

        private static void IsLongTextReadOnlyChanged(DependencyObject obj,
    DependencyPropertyChangedEventArgs e)
        {
            LongTextColumn col = (LongTextColumn)obj;
            col.OnPropertyChanged("IsLongTextReadOnly");
        }

        public readonly static DependencyProperty IsLongTextDialogResizableProperty =
     DependencyProperty.Register("IsLongTextDialogResizable", typeof(ResizeMode), typeof(LongTextColumn), new PropertyMetadata(ResizeMode.NoResize));

        public ResizeMode IsLongTextDialogResizable
        {
            get { return (ResizeMode)GetValue(IsLongTextDialogResizableProperty); }
            set
            {
                SetValue(IsLongTextDialogResizableProperty, value);
            }
        }
    }
   
}
