﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using Infragistics.Controls.Grids;
using Infragistics.Controls.Grids.Primitives;

namespace LongTextColumnPOC
{
    public abstract class TextColumnContentProviderBase : ColumnContentProviderBase
    {
        private const int Padding = 6;
        private const string ActualWidthPropName = "ActualWidth";

        protected TextBlock TextControl { private set; get; }

        protected TextColumnContentProviderBase()
        {
            TextControl = new TextBlock
            {
                TextTrimming = TextTrimming.CharacterEllipsis,
                SnapsToDevicePixels = true,
                HorizontalAlignment = HorizontalAlignment.Stretch,

            };
            ToolTipService.SetShowOnDisabled(TextControl, true);
        }

        private void PropertyChangedEvent(object sender, PropertyChangedEventArgs e)
        {
            var column = sender as EditableColumn;

            if (e.PropertyName == ActualWidthPropName && column != null)
            {
                if (column.Width.HasValue)
                {
                    SetWidth(column.Width.Value.Value);
                }
                else if (Math.Abs(column.ActualWidth - 0) > double.Epsilon)
                {
                    SetWidth(column.ActualWidth);
                }
            }
        }

        public override FrameworkElement ResolveDisplayElement(Cell cell, Binding cellBinding)
        {
            SetWidth(cell.Column.ActualWidth);

            if (cellBinding != null)
            {
                cellBinding.ValidatesOnDataErrors = true;
                cellBinding.NotifyOnValidationError = true;

                TextControl.SetBinding(TextBlock.TextProperty, cellBinding);
            }

            SetTooltip(cell.Value as string);

            cell.Column.PropertyChanged += PropertyChangedEvent;

            return TextControl;
        }

        protected void SetWidth(double width)
        {
            TextControl.Width = Math.Max(width - Padding, 0);
        }

        protected void SetTooltip(string tooltip)
        {
            if (String.IsNullOrWhiteSpace(tooltip) == false)
            {
                TextControl.ToolTip = tooltip;
            }
            else
            {
                TextControl.ToolTip = null;
            }
        }

        internal static void SetControlStyle(FrameworkElement control, Style style)
        {
            if (control != null)
            {
                if (style == null)
                {
                    if (control.Style != null)
                    {
                        control.ClearValue(FrameworkElement.StyleProperty);
                    }
                }
                else
                {
                    control.SetValue(FrameworkElement.StyleProperty, style);
                }
            }
        }
    }
}
